pub struct Address {
    pub name: String,
    pub address_line1: String,
    pub address_line2: Option<String>,
    pub district_or_county: Option<String>,
    pub city: String,
    pub state_or_province_code: String,
    pub country_code: String,
    pub postal_code: String,
}

Fields

name: String

Name of the individual or business.

address_line1: String

The street address information.

address_line2: Option<String>

Additional street address information, if required.

district_or_county: Option<String>

The district or county.

city: String

The city.

state_or_province_code: String

The state or province code. If state or province codes are used in your marketplace, it is recommended that you include one with your request. This helps Amazon to select the most appropriate Amazon fulfillment center for your inbound shipment plan.

country_code: String

The country code in two-character ISO 3166-1 alpha-2 format.

postal_code: String

The postal code. If postal codes are used in your marketplace, we recommended that you include one with your request. This helps Amazon select the most appropriate Amazon fulfillment center for the inbound shipment plan.

Implementations